@@ -5,17 +5,19 @@
  *      Author: M. Baaske
  */
 
-#include <R_ext/Rdynload.h>
+//#include <R_ext/Rdynload.h>
 
 #include "unfold.h"
 #include "SimPoisson.h"
 
 #ifdef _OPENMP
  #include <omp.h>
- #include <R_ext/MathThreads.h>
+ //#include <R_ext/MathThreads.h>
  static int nthreads=1;
 #endif
 
+#include <R_ext/Rdynload.h>
+
 #define DIM_SIZE 6
 #define DIM_SIZE_HIST 3
 
